YARP 2.2.3 (2009-05-22)                                                {#v2_2_3}
=======================

Contributors
------------

This is a list of people that contributed to this release (generated from the
git history using `git shortlog -ens --no-merges v2.2.2...v2.2.3`):

```
    76	Paul Fitzpatrick <paulfitz@alum.mit.edu>
    39	Lorenzo Natale <lorenzo.natale@iit.it>
    25	YARP Developers <yarp0-devel@lists.sourceforge.net>
     9	Alessandro Scalzo <alessandro.scalzo@iit.it>
     6	Francesco Nori <francesco.nori@iit.it>
     1	Giacomo Spigler <spiglerg@gmail.com>
     1	Ugo Pattacini <ugo.pattacini@iit.it>
```
